GamsSolver

Enum GamsSolver 

pub enum GamsSolver {
Show 34 variants AlphaEcp, Antigone, Baron, Cbc, Conopt, Copt, Cplex, Decis, Dicopt, Glpk, Gurobi, Guss, Highs, Ipopt, Jams, Kestrel, Knitro, Lindo, LindoGlobal, Miles, Minos, Mosek, Nlpec, OdhCplex, Path, QuadMinos, Reshop, Sbb, Scip, Shot, Snopt, Soplex, Xpress, Custom(String),
}
Available on crate feature gams only.
Named GAMS sub-solver. Use GamsSolver::Custom for any name that isn’t a pre-enumerated variant.

Reference: https://www.gams.com/latest/docs/S_MAIN.html#SOLVERS_MODEL_TYPES

Variants



AlphaEcp

ALPHAECP: MINLP, MIQCP



Antigone

ANTIGONE: NLP, CNS, DNLP, MINLP, QCP, MIQCP, Global



Baron

BARON: LP, MIP, NLP, CNS, DNLP, MINLP, QCP, MIQCP, Global



Cbc

CBC: LP, MIP



Conopt

CONOPT: LP, NLP, CNS, DNLP, QCP



Copt

COPT: LP, MIP, QCP, MIQCP



Cplex

CPLEX: LP, MIP, QCP, MIQCP



Decis

DECIS: LP, Stochastic



Dicopt

DICOPT: MINLP, MIQCP



Glpk

GLPK: LP, MIP (not in GAMS docs but recognized)



Gurobi

GUROBI: LP, MIP, NLP, DNLP, MINLP, QCP, MIQCP, Global



Guss

GUSS: LP, MIP, NLP, MCP, CNS, DNLP, MINLP, QCP, MIQCP



Highs

HiGHS: LP, MIP



Ipopt

IPOPT: LP, NLP, CNS, DNLP, QCP



Jams

JAMS: EMP



Kestrel

KESTREL: all model types (remote solver submission)



Knitro

KNITRO: LP, NLP, MCP, MPEC, CNS, DNLP, MINLP, QCP, MIQCP



Lindo

LINDO: LP, MIP, NLP, DNLP, MINLP, QCP, MIQCP, Stochastic, Global



LindoGlobal

LINDOGLOBAL: LP, MIP, NLP, DNLP, MINLP, QCP, MIQCP, Global



Miles

MILES: MCP



Minos

MINOS: LP, NLP, CNS, DNLP, QCP



Mosek

MOSEK: LP, MIP, NLP, DNLP, MINLP, QCP, MIQCP



Nlpec

NLPEC: MCP, MPEC



OdhCplex

ODHCPLEX: MIP, MIQCP



Path

PATH: MCP, CNS



QuadMinos

QUADMINOS: LP



Reshop

RESHOP: EMP



Sbb

SBB: MINLP, MIQCP



Scip

SCIP: MIP, NLP, CNS, DNLP, MINLP, QCP, MIQCP, Global



Shot

SHOT: MINLP, MIQCP



Snopt

SNOPT: LP, NLP, CNS, DNLP, QCP



Soplex

SOPLEX: LP



Xpress

XPRESS: LP, MIP, NLP, CNS, DNLP, MINLP, QCP, MIQCP, Global



Custom(String)

Any other GAMS-recognized solver name, emitted verbatim.

Implementations

Source

impl GamsSolver

pub fn name(&self) -> &str

GAMS solver keyword used in the option {LP|MIP} = ...; statement.